@@ -128,32 +128,14 @@ class GetterApp(Singleton, QApplication):
         self.load_themes()  # Depends on icon_store, settings, themes, theme_index_map
         self.load_icons()   # Depends on icon_store, session
 
-        # Register callables to events
-        EventBus['settings'] = self.settings.event_bus
-        EventBus['settings'].subscribe(
-            DeferredCallable(self.load_themes),
-            TomlEvents.Import)
-
-        EventBus['settings'].subscribe(
-            DeferredCallable(self.updateTranslations.emit),
-            TomlEvents.Import)
-
-        EventBus['settings'].subscribe(
-            DeferredCallable(self.update_stylesheet),
-            TomlEvents.Set, event_predicate=lambda e: e.key == 'gui/themes/selected')
-
-        self.updateTranslations.connect(lambda: self.translator.__setattr__('language', self.settings['language']))
-        self.updateTranslations.connect(lambda: self.setApplicationDisplayName(self.translator('app.name')))
-        self.updateTranslations.connect(self._registered_translations)
-        self.updateTranslations.connect(self._translate_http_code_map)
-
         if not self.settings['ignore_updates']:
             self.version_checker.newerVersion.connect(self._upgrade_version_dialog)
 
         # Must load client last, but before windows
         self.load_env(verbose=True)
         self.client = Client(self)
-        self._connect_authenticator()
+        self.update_client_proxy()
+        self._connect_events()
 
         # Setup window instances
         self._create_windows()
@@ -174,20 +156,6 @@ class GetterApp(Singleton, QApplication):
         """Return a copy of the self._windows dictionary."""
         return self._windows.copy()
 
-    def _connect_authenticator(self) -> None:
-        self.client.authenticationRequired.connect(
-            lambda: self.show_dialog('warnings.empty_token')
-        )
-
-        self.client.authenticator.authenticationSuccessful.connect(
-            lambda _, user: self.show_dialog('information.authentication_success', description_args=(user.email,))
-        )
-
-        self.client.authenticator.authenticationFailed.connect(
-            lambda email, e: self.show_dialog('errors.authentication_failed', description_args=(email, e),
-                                              details_text=format_tb(e.__traceback__))
-        )
-
     def _create_paths(self) -> None:
         """Create files and directories if they do not exist."""
         for dir_path in (CG_CACHE_PATH, CG_CONFIG_PATH):
@@ -234,6 +202,39 @@ class GetterApp(Singleton, QApplication):
         for code in (400, 401, 403, 404, 405, 406):
             http_code_map[code] = (http_code_map[code][0], self.translator(f'network.http.codes.{code}.description'))
 
+    def _connect_events(self) -> None:
+        EventBus['settings'] = self.settings.event_bus
+        EventBus['settings'].subscribe(
+            DeferredCallable(self.load_themes),
+            TomlEvents.Import)
+
+        EventBus['settings'].subscribe(
+            DeferredCallable(self.updateTranslations.emit),
+            TomlEvents.Import)
+
+        EventBus['settings'].subscribe(
+            DeferredCallable(self.update_stylesheet),
+            TomlEvents.Set, event_predicate=lambda e: e.key == 'gui/themes/selected')
+
+        EventBus['settings'].subscribe(
+            DeferredCallable(self.update_client_proxy),
+            TomlEvents.Set, lambda event: event.key == 'network/proxy/protocol' and not event.new)
+
+        self.updateTranslations.connect(lambda: setattr(self.translator, 'language', self.settings['language']))
+        self.updateTranslations.connect(lambda: self.setApplicationDisplayName(self.translator('app.name')))
+        self.updateTranslations.connect(self._registered_translations)
+        self.updateTranslations.connect(self._translate_http_code_map)
+
+        self.client.authenticationRequired.connect(
+            lambda: self.show_dialog('warnings.empty_token'))
+
+        self.client.authenticator.authenticationSuccessful.connect(
+            lambda sess: self.show_dialog('information.authentication_success', description_args=(sess.user.email,)))
+
+        self.client.authenticator.authenticationFailed.connect(
+            lambda email, e: self.show_dialog('errors.authentication_failed', description_args=(email, e),
+                                              details_text=format_tb(e.__traceback__)))
+
     def init_translations(self, translation_calls: dict[Callable, str | tuple[Any, ...]]) -> None:
         """Initialize the translation of all objects.
 
@@ -574,3 +575,25 @@ class GetterApp(Singleton, QApplication):
     def start_worker(self, runnable: Callable | QRunnable, priority: int = 0) -> None:
         """Start a runnable from the application :py:class:`QThreadPool`."""
         self._thread_pool.start(runnable, priority)
+
+    def update_client_proxy(self) -> None:
+        """Update the client proxy with the current application settings."""
+        if protocol := self.settings['network/proxy/protocol']:
+            host: str = self.settings['network/proxy/host']  # type: ignore
+            port: int = self.settings['network/proxy/port']  # type: ignore
+
+            if not (host and port):
+                return
+
+            protocol_str = 'socks5' if protocol == 2 else 'http'
+            protocol_str = f'{protocol_str}://'
+
+            # Format login information from our proxy
+            if login := self.settings['network/proxy/username']:
+                if password := self.settings['network/proxy/password']:
+                    login = f'{login}:{password}'
+                login = f'{login}@'
+
+            self.client.proxy = f'{protocol_str}{login}{host}:{port}'
+        else:
+            del self.client.proxy
